@@ -599,16 +599,16 @@ static __forceinline unsigned __int64 _re_atomic_load(
 
 	switch (size) {
 	case 1u:
-		v = __iso_volatile_load8((const unsigned __int8*)a);
+		v = __iso_volatile_load8((const volatile __int8*)a);
 		break;
 	case 2u:
-		v = __iso_volatile_load16((const unsigned __int16*)a);
+		v = __iso_volatile_load16((const volatile __int16*)a);
 		break;
 	case 4u:
-		v = __iso_volatile_load32((const unsigned __int32*)a);
+		v = __iso_volatile_load32((const volatile __int32*)a);
 		break;
 	default:
-		v = __iso_volatile_load64((const unsigned __int64*)a);
+		v = __iso_volatile_load64((const volatile __int64*)a);
 		break;
 	}
 
