@@ -32,6 +32,8 @@ enum h265_naltype {
 	H265_NAL_IDR_W_RADL      = 19,
 	H265_NAL_IDR_N_LP        = 20,
 	H265_NAL_CRA_NUT         = 21,
+	H265_NAL_RSV_IRAP_VCL22  = 22,
+	H265_NAL_RSV_IRAP_VCL23  = 23,
 
 	/* non-VCL class */
 	H265_NAL_VPS_NUT         = 32,
@@ -51,6 +53,7 @@ enum h265_naltype {
 
 struct h265_nal {
 	unsigned nal_unit_type:6;          /* NAL unit type (0-40)       */
+	unsigned nuh_layer_id:6;           /* layer identifier           */
 	unsigned nuh_temporal_id_plus1:3;  /* temporal identifier plus 1 */
 };
 
@@ -58,7 +61,7 @@ void h265_nal_encode(uint8_t buf[2], unsigned nal_unit_type,
 		     unsigned nuh_temporal_id_plus1);
 int  h265_nal_encode_mbuf(struct mbuf *mb, const struct h265_nal *nal);
 int  h265_nal_decode(struct h265_nal *nal, const uint8_t *p);
-void h265_nal_print(const struct h265_nal *nal);
+int  h265_nal_print(struct re_printf *pf, const struct h265_nal *nal);
 const char *h265_nalunit_name(enum h265_naltype type);
 bool h265_is_keyframe(enum h265_naltype type);
 
