@@ -6,19 +6,13 @@
 
 
 /**
- * @def MOD_PRE
- *
- * Module Prefix
- *
  * @def MOD_EXT
  *
  * Module Extension
  */
 #if defined (WIN32)
-#define MOD_PRE ""
 #define MOD_EXT ".dll"
 #else
-#define MOD_PRE ""
 #define MOD_EXT ".so"
 #endif
 
