@@ -348,6 +348,20 @@ static inline int16_t rtp_seq_diff(uint16_t x, uint16_t y)
 }
 
 
+/**
+ * Compare two RTP sequence numbers
+ *
+ * @param x First sequence number
+ * @param y Second sequence number
+ *
+ * @return true if x is less than y; false otherwise
+ */
+static inline bool rtp_seq_less(uint16_t x, uint16_t y)
+{
+	return ((int16_t)(x - y)) < 0;
+}
+
+
 /** NTP Time */
 struct rtp_ntp_time {
 	uint32_t hi;  /**< Seconds since 0h UTC on 1 January 1900 */
@@ -383,3 +397,19 @@ void rtp_source_calc_jitter(struct rtp_source *s, uint32_t rtp_ts,
 			uint32_t arrival);
 int  rtp_source_calc_lost(const struct rtp_source *s);
 uint8_t rtp_source_calc_fraction_lost(struct rtp_source *s);
+
+
+/** RTP Extensions for Transport-wide Congestion Control */
+enum twcc_packet_state {
+	TWCC_PK_NOT_RECEIVED = 0,/**< Packet not received                   */
+	TWCC_PK_RECEIVED,        /**< Packet received, small delta          */
+	TWCC_PK_LARGE_DELTA      /**< Packet received, large or neg. delta  */
+};
+
+struct rtcp_twcc_packet {
+	struct le le;
+	uint64_t ts;
+	int32_t delta;
+	enum twcc_packet_state state;
+	uint16_t tseq;
+};
